How to import Nany's library is as follows:

<< from Nanylibrary.Nany import Nany_Robot >>

An example:

from Nanylibrary.Nany import Nany_Robot

bot = Nany_Robot("Your Auth Account")


Made by Team Nanymous

Address of our team's GitHub :

https://github.com/Nanymous/Nany_library.git